==> schemacrawler-16.21.3-sources.jar: us/fatehi/utility/ioresource/ClasspathInputResource.java <==
/*
========================================================================
SchemaCrawler
http://www.schemacrawler.com
Copyright (c) 2000-2024, Sualeh Fatehi <sualeh@hotmail.com>.
All rights reserved.
------------------------------------------------------------------------

SchemaCrawler is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

SchemaCrawler and the accompanying materials are made available under
the terms of the Eclipse Public License v1.0, GNU General Public License
v3 or GNU Lesser General Public License v3.

You may elect to redistribute this code under any of these licenses.

The Eclipse Public License is available at:
http://www.eclipse.org/legal/epl-v10.html

The GNU General Public License v3 and the GNU Lesser General Public
License v3 are available at:
http://www.gnu.org/licenses/

========================================================================
*/

package us.fatehi.utility.ioresource;

import static us.fatehi.utility.ioresource.InputResourceUtility.wrapReader;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.nio.charset.Charset;
import java.util.logging.Level;
import java.util.logging.Logger;
import static java.util.Objects.requireNonNull;

public class ClasspathInputResource implements InputResource {

  private static final Logger LOGGER = Logger.getLogger(ClasspathInputResource.class.getName());

  private final String classpathResource;

  public ClasspathInputResource(final String classpathResource) throws IOException {
    this.classpathResource = requireNonNull(classpathResource, "No classpath resource provided");
    if (ClasspathInputResource.class.getResource(this.classpathResource) == null) {
      final IOException e =
          new IOException("Cannot read classpath resource, " + this.classpathResource);
      LOGGER.log(Level.FINE, e.getMessage(), e);
      throw e;
    }
  }

  public String getClasspathResource() {
    return classpathResource;
  }

  @Override
  public String getDescription() {
    String url;
    try {
      url = ClasspathInputResource.class.getResource(classpathResource).toExternalForm();
    } catch (final Exception e) {
      url = classpathResource;
    }
    return url;
  }

  @Override
  public Reader openNewInputReader(final Charset charset) {
    requireNonNull(charset, "No input charset provided");
    final InputStream inputStream =
        ClasspathInputResource.class.getResourceAsStream(classpathResource);
    if (inputStream == null) {
      throw new NullPointerException(
          String.format("Cannot open classpath resource <%s> for reading", classpathResource));
    }
    final Reader reader = new BufferedReader(new InputStreamReader(inputStream, charset));
    LOGGER.log(Level.INFO, "Opened input reader to classpath resource, " + classpathResource);

    return wrapReader(getDescription(), reader, true);
  }

  @Override
  public String toString() {
    return classpathResource;
  }
}

==> schemacrawler-16.25.1-sources.jar: us/fatehi/utility/ioresource/ClasspathInputResource.java <==
/*
========================================================================
SchemaCrawler
http://www.schemacrawler.com
Copyright (c) 2000-2025, Sualeh Fatehi <sualeh@hotmail.com>.
All rights reserved.
------------------------------------------------------------------------

SchemaCrawler is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

SchemaCrawler and the accompanying materials are made available under
the terms of the Eclipse Public License v1.0, GNU General Public License
v3 or GNU Lesser General Public License v3.

You may elect to redistribute this code under any of these licenses.

The Eclipse Public License is available at:
http://www.eclipse.org/legal/epl-v10.html

The GNU General Public License v3 and the GNU Lesser General Public
License v3 are available at:
http://www.gnu.org/licenses/

========================================================================
*/

package us.fatehi.utility.ioresource;

import static java.util.Objects.requireNonNull;
import static us.fatehi.utility.IOUtility.locateResource;

import java.io.IOException;
import java.io.InputStream;
import java.net.URL;

/**
 * Converts a provided classpath resource into an input resource. NOTE: Always assumes that
 * resources are absolute. Leading slashes are not required, but ignored if provided.
 */
public class ClasspathInputResource extends BaseInputResource {

  private URL url;

  public ClasspathInputResource(final String classpathResource) throws IOException {
    requireNonNull(classpathResource, "No classpath resource provided");
    url = locateResource(classpathResource);
    if (url == null) {
      final IOException e =
          new IOException(String.format("Cannot read classpath resource, <%s>", classpathResource));
      throw e;
    }
  }

  @Override
  public InputStream openNewInputStream() throws IOException {
    final InputStream inputStream = url.openStream();
    return inputStream;
  }

  @Override
  public String toString() {
    return url.toExternalForm();
  }
}
